==> jc-huazhu-client-0.0.7-sources.jar: com/xforceplus/jchuazhu/controller/AuditInvoiceDtoFeignApi.java <==
package com.xforceplus.jchuazhu.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-11-08
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.jchuazhu.entity.AuditInvoiceDto;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-huazhu")
public interface AuditInvoiceDtoFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/auditInvoiceDto/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param auditInvoiceDto ${table.comment}
   * @return R
   */
  @PostMapping("/auditInvoiceDto/add")
  public R save(@RequestBody AuditInvoiceDto auditInvoiceDto);

  /**
   * 修改${table.comment}
   * @param auditInvoiceDto ${table.comment}
   * @return R
   */
  @PostMapping("/auditInvoiceDto/update")
  public R updateById(@RequestBody AuditInvoiceDto auditInvoiceDto);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/auditInvoiceDto/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-huazhu-client-0.0.98-sources.jar: com/xforceplus/jchuazhu/controller/AuditInvoiceDtoFeignApi.java <==
package com.xforceplus.jchuazhu.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2023-05-04
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.jchuazhu.entity.AuditInvoiceDto;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-huazhu")
public interface AuditInvoiceDtoFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/auditInvoiceDto/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param auditInvoiceDto ${table.comment}
   * @return R
   */
  @PostMapping("/auditInvoiceDto/add")
  public R save(@RequestBody AuditInvoiceDto auditInvoiceDto);

  /**
   * 修改${table.comment}
   * @param auditInvoiceDto ${table.comment}
   * @return R
   */
  @PostMapping("/auditInvoiceDto/update")
  public R updateById(@RequestBody AuditInvoiceDto auditInvoiceDto);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/auditInvoiceDto/del/{id}" )
  public R removeById(@PathVariable Long id);

}
